<?php
// $Id: template.php,v 1.21 2009/03/01 13:05:03 shannonlucas Exp $
/**
 * @file The Nitobe theme.
 */

require_once path_to_nitobetheme() . '/nitobe_utils.php';


/**
 * Return the path to the main nitobe theme directory.
 */
function path_to_nitobetheme() {
  static $theme_path;

  if (!isset($theme_path)) {
    global $theme;
    if ($theme == 'nitobe') {
      $theme_path = path_to_theme();
    }
    else {
      $theme_path = drupal_get_path('theme', 'nitobe');
    }
  }
  return $theme_path;
}


/**
 * Implementation of hook_theme().
 *
 * @param array  $existing
 * @param string $type
 * @param string $theme
 * @param string $path
 *
 * @return array
 */
function nitobe_theme($existing, $type, $theme, $path) {
  $funcs = array(
    'nitobe_username' => array(
      'arguments' => $existing['theme_username'],
    ),
    'nitobe_preprocess_page' => array(
      'arguments' => $existing['phptemplate_preprocess_page'],
    ),
    'nitobe_preprocess' => array(
      'arguments' => $existing['template_preprocess'],
    ),
    'nitobe_preprocess_comment' => array(
      'arguments' => $existing['phptemplate_preprocess_comment'],
    ),
    'nitobe_preprocess_user_picture' => array(
      'arguments' => $existing['phptemplate_preprocess_user_picture'],
    ),
  );

  nitobe_settings_init($theme);

  return $funcs;
}


/**
 * Display the list of available node types for node creation.
 *
 * @param $content array
 *
 * @return string The rendered HTML.
 */
function nitobe_node_add_list($content) {
  $output = '';

  if ($content) {
    $output = '<dl class="node-type-list">';
    $class = 'odd';
    foreach ($content as $item) {
      $output .= '<dt class="' . $class . '">'. l($item['title'], $item['href'], $item['options']) .'</dt>';
      $output .= '<dd class="' . $class . '">'. filter_xss_admin($item['description']) .'</dd>';

      $class = ($class == 'odd') ? 'even' : 'odd';
    }
    $output .= '</dl>';
  }
  return $output;
}


/**
 * Decorates theme_username().
 *
 * @param object $object An instance of a node, comment, etc.
 *
 * @return string The decorated output from theme_username().
 */
function nitobe_username($object) {
  $output = theme_username($object);

  if ((boolean)theme_get_setting('nitobe_remove_not_verified')) {
    $to_strip = ' ('. t('not verified') .')';
    $output = str_replace($to_strip, '', $output);
  }

  return $output;
}


/**
 * Prepare the user pictures for rendering.
 *
 * @param &$variables array The associative array of template arguments.
 */
function nitobe_preprocess_user_picture(&$variables) {
  $variables['picture'] = '';

  if (variable_get('user_pictures', 0)) {
    $account = $variables['account'];
    if (!empty($account->picture) && file_exists($account->picture)) {
      $picture = file_create_url($account->picture);
    }
    else if (variable_get('user_picture_default', '')) {
      $picture = variable_get('user_picture_default', '');
    }
    else {
      $picture = path_to_nitobetheme() . '/user-icon.jpg';
    }

    if (isset($picture)) {
      $name = $account->name ? $account->name : variable_get('anonymous', t('Anonymous'));
      $alt  = t("@user's picture", array('@user' => $name));
      $attr = array('class' => 'user-picture');
      $variables['picture'] = theme('image', $picture, $alt, $alt, $attr, FALSE);

      // Link the picture if allowed.
      if (!empty($account->uid) && user_access('access user profiles')) {
        $attributes = array('attributes' => array('title' => t('View user profile.')), 'html' => TRUE);
        $variables['picture'] = l($variables['picture'], "user/$account->uid", $attributes);
      }
    }
  }
}


/**
 * Determine whether to show the date stamp for the given node.
 *
 * @param $type string The machine readable name of the type to check.
 *
 * @return boolean TRUE if the node is of a type that should show the date
 *         stamp, FALSE if not.
 */
function nitobe_show_datestamp($type) {
  $default     = drupal_map_assoc(array('blog', 'forum', 'poll', 'story'));
  $valid_types = theme_get_setting('nitobe_show_datestamp');
  $valid_types = (!empty($valid_types)) ? $valid_types : $default;

  return (array_key_exists($type, $valid_types) && ($valid_types[$type] === $type));
}


/**
 * Removes the spaces between words in the given string and returns an HTML
 * string with every other word wrapped in a span with the class "alt-color".
 *
 * @param $text string The text to render.
 *
 * @return string The rendered HTML.
 */
function nitobe_alt_word_text($text = '') {
  $words  = explode(' ', $text);
  $result = '';

  if (is_array($words)) {
    $alt = FALSE;
    foreach ($words as $word) {
      if ($alt) {
        $result .= '<span class="alt-color">' . $word . '</span>';
      }
      else {
        $result .= $word;
      }

      $alt = !$alt;
    }
  }

  return $result;
}


/**
 * Render the node terms with a text prefix and join them with a comma.
 *
 * @param $node object The node to render term links for.
 * @param $prefix string The text to show before the list of terms. By
 *        defaults the localized text 'Tags:' is used.
 * @param $separator string The character(s) to place between the terms. By
 *        default a comma is used.
 */
function nitobe_render_terms($node, $prefix = NULL, $separator = ',') {
  $prefix = ($prefix == NULL) ? t('Tags:') : $prefix;
  $output = '';

  if (module_exists('taxonomy')) {
    $terms = taxonomy_link('taxonomy terms', $node);
  }
  else {
    $terms = array();
  }

  if (count($terms) > 0) {
    $output  .= $prefix . ' <ul class="links inline">';
    $rendered = nitobe_list_of_links($terms);

    $i = 1;
    foreach ($rendered as $term) {
      $output .= '<li class="' . $term[1] . '">' . $term[0];

      if ($i < count($terms)) {
        $output .= $separator . ' ';
      }

      $output .= '</li>';

      $i++;
    }

    $output .= '</ul>';
  }

  return $output;
}


/**
 * Returns an array of rendered lists without any wrapping elements such as
 * <ul> and <li>.
 *
 * @param $links array A keyed array of links to be themed.
 *
 * @return array An array of arrays. The first element of each inner array
 *         will be the rendered link. The second element will be the CSS
 *         class that should be applied to any wrapping element of that
 *         link.
 */
function nitobe_list_of_links($links) {
  $output = array();

  if (count($links) > 0) {
    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = $key;

      // Add first, last and active classes to the list of links to help
      // out themers.
      if ($i == 1) {
        $class .= ' first';
      }
      if ($i == $num_links) {
        $class .= ' last';
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))) {
        $class .= ' active';
      }

      $output[] = array(nitobe_single_link($link), $class);

      $i++;
    }
  }

  return $output;
}


/**
 * Render a single link instance.
 *
 * @param $link array The array of options to use when rendering the link.
 *
 * @return string The rendered HTML link or span element if no href was
 *         provided in the given link.
 */
function nitobe_single_link($link) {
  if (isset($link['href']) || isset($link['fragment'])) {
    // Pass in $link as $options, they share the same keys.
    return l($link['title'], $link['href'], $link);
  }
  else if (!empty($link['title'])) {
    // Some links are actually not links, but we wrap these in <span> for
    // adding title and class attributes
    if (empty($link['html'])) {
      $link['title'] = check_plain($link['title']);
    }

    $span_attributes = '';
    if (isset($link['attributes'])) {
      $span_attributes = drupal_attributes($link['attributes']);
    }

    $span = '<span'. $span_attributes .'>'. $link['title'] .'</span>';

    return $span;
  }
}


/**
 * Return the comment link to display for a node rendered as a teaser.
 *
 * @param $node object The node to render the comment link for.
 * @param $teaser boolean Whether or not this call is in the context of
 *        rendering a teaser.
 *
 * @return string The rendered comment link.
 */
function nitobe_comment_link($node, $teaser = FALSE) {
  $separate = (variable_get('comment_form_location_'. $node->type, COMMENT_FORM_SEPARATE_PAGE) == COMMENT_FORM_SEPARATE_PAGE);
  $link     = NULL;

  if (!empty($node->links)) {
    $links = $node->links;

    if (!empty($links['comment_forbidden'])) {
      $link = $links['comment_forbidden'];
    }
    else if (!empty($links['comment_new_comments'])) {
      $link = $links['comment_new_comments'];
      $link['title'] = format_plural($node->comment_count,
                                     '1 New Comment', '@count New Comments');

      if ($node->comment == COMMENT_NODE_READ_WRITE) {
        $link['attributes']['title'] = t('Read new comments or comment on @title',
                                         array('@title' => $node->title));
      }
      else {
        $link['attributes']['title'] = t('Read new comments for @title',
                                         array('@title' => $node->title));
      }
    }
    else if (!empty($links['comment_comments'])) {
      $link = $links['comment_comments'];
      $link['title'] = format_plural($node->comment_count,
                                     '1 Comment', '@count Comments');

      if ($node->comment == COMMENT_NODE_READ_WRITE) {
        $link['attributes']['title'] = t('Read comments or comment on @title',
                                         array('@title' => $node->title));
      }
      else {
        $link['attributes']['title'] = t('Read comments for @title',
                                         array('@title' => $node->title));
      }

      if (!$separate) {
        $link['href'] = "node/{$node->nid}";
      }
    }
    else if (!empty($links['comment_add'])) {
      $link          = $links['comment_add'];
      $link['title'] = t('Add a Comment');
      $link['attributes']['title'] = t('Comment on @title', array('@title' => $node->title));;

      if (!$separate) {
        $link['href'] = "node/{$node->nid}";
      }
    }
  }
  else if ($node->comment == COMMENT_NODE_READ_WRITE) {
    $url = ($separate == TRUE) ? "comment/reply/{$node->nid}" : "node/{$node->nid}";

    $link = array(
      'title'      => t('Add a Comment'),
      'href'       => $url,
      'fragment'   => 'comment-form',
      'attributes' => array('title' => t('Comment on @title',
                                         array('@title' => $node->title))),
    );
  }

  return ($link != NULL) ? nitobe_single_link($link) : '';
}


/**
 * Create the 'Continue reading' link for the bottom of posts.
 *
 * @param $node object The node to add the continue reading link to.
 *
 * @return string The link HTML.
 */
function nitobe_read_more_link($node) {
  if ($node != NULL) {
    $link_text  = t('Continue reading...');
    $link_title = t('Continue reading !title.', array('!title' => $node->title));
    $options = array(
      'attributes' => array('title' => $link_title),
      'html' => TRUE,
    );
    return l($link_text, 'node/' . $node->nid, $options);
  }

  return '';
}


/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return a string containing the breadcrumb output.
 */
function phptemplate_breadcrumb($breadcrumb) {
  $show_single = (boolean)theme_get_setting('nitobe_show_single_crumb');

  if ((count($breadcrumb) == 1) && !$show_single) {
    return '';
    }

  return theme_breadcrumb($breadcrumb);
}


/**
 * Allow themable wrapping of all comments.
 *
 * @param $content string The comments to wrap.
 * @param $node object The node the comments belong to.
 *
 * @return string The rendered HTML.
 */
function phptemplate_comment_wrapper($content, $node) {
  if (!$content || $node->type == 'forum') {
    return '<div id="comments">'. $content .'</div>';
  }
  else {
    return '<div id="comments"><h2 class="comments">'. t('Comments') .'</h2>'. $content .'</div>';
  }
}


/**
 * Insert variables at the beginning of the theming process.
 */
function nitobe_preprocess(&$vars, $hook) {
  static $has_sidebar;

  if (!isset($has_sidebar)) {
    $left  = count(block_list('left'));
    $right = count(block_list('right'));
    $has_sidebar = (($left + $right) > 0);
  }

  $vars['nitobe_has_sidebar'] = $has_sidebar;
}


/**
 * Override or insert PHPTemplate variables into the templates.
 */
function nitobe_preprocess_page(&$vars) {
  $vars['tabs2'] = menu_secondary_local_tasks();

  // Determine if the masthead image should be displayed.
  $force_header = theme_get_setting('nitobe_header_always_show');
  $masthead     = $vars['masthead'];

  if ($force_header || empty($masthead)) {
    // Determine the header image if it is set, or add the JavaScript for
    // random header images.
    $header_img = theme_get_setting('nitobe_header_image');
    $header_img = empty($header_img) ? '<random>' : $header_img;

    if ($header_img == '<random>') {
      $vars['closure'] .= _nitobe_random_header_js();

      // Add css for a random image for browsers without js enabled.
      // Patch supplied by Jonathan Hedstrom ( http://drupal.org/user/208732 )
      $image = array_rand(_nitobe_get_header_list());
      $vars['styles'] .= _nitobe_fixed_header_css($image) . "\n";
    }
    else {
      $vars['styles'] .= _nitobe_fixed_header_css($header_img) . "\n";
    }
  }
}


/**
 * Overrides template_preprocess_comment(). Allows for the removal of the
 * 'reply' link.
 *
 * @param array $variables
 */
function nitobe_preprocess_comment(&$variables) {
  $comment = $variables['comment'];
  $node    = $variables['node'];

  $variables['author']  = theme('username', $comment);
  $variables['content'] = $comment->comment;

  $params = array(
    '@date' => format_date($comment->timestamp, 'custom', 'M jS, Y'),
    '@time' => format_date($comment->timestamp, 'custom', 'g:i a'),
  );
  $variables['date']    = t('@date at @time', $params);

  //--------------------------------------------------------------------------
  // In order to remove the 'reply' link, it's necessary to get them again as
  // an array. By the time this function is called, they have already been
  // rendered as HTML.
  $linkage        = module_invoke_all('link', 'comment', $comment);
  $suppress_reply = (boolean)theme_get_setting('nitobe_suppress_comment_reply');

  if ($suppress_reply) {
    unset($linkage['comment_reply']);
  }

  $links              = theme('links', $linkage);
  $links              = preg_replace('!</li>\n<li!', ' | </li><li', $links);
  $variables['links'] = $links;
}


/**
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs. Overridden to split the secondary tasks.
 *
 * @ingroup themeable
 */
function phptemplate_menu_local_tasks() {
  return menu_primary_local_tasks();
}

function phptemplate_comment_submitted($comment) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $comment),
      '!datetime' => format_date($comment->timestamp)
    ));
}

function phptemplate_node_submitted($node) {
  return t('!datetime — !username',
    array(
      '!username' => theme('username', $node),
      '!datetime' => format_date($node->created),
    ));
}


/**
 * Read the theme settings' default values from the .info and save them into
 * the database.
 *
 * @param string $theme The actual name of theme that is being being checked.
 */
function nitobe_settings_init($theme) {
  $themes = list_themes();

  // Get the default values from the .info file.
  $defaults = $themes[$theme]->info['settings'];

  // Get the theme settings saved in the database.
  $settings = theme_get_settings($theme);

  // Don't save the toggle_node_info_ variables.
  if (module_exists('node')) {
    foreach (node_get_types() as $type => $name) {
      unset($settings['toggle_node_info_' . $type]);
    }
  }

  // Save default theme settings.
  variable_set(
    str_replace('/', '_', 'theme_' . $theme . '_settings'),
    array_merge($defaults, $settings)
  );

  // Force refresh of Drupal internals.
  theme_get_setting('', TRUE);
}



